@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_elastictranscoder import ElasticTranscoderClient
 
-    session = boto3.Session()
-
     client: ElasticTranscoderClient = boto3.client("elastictranscoder")
-    session_client: ElasticTranscoderClient = session.client("elastictranscoder")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
