@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_elastictranscoder import ElasticTranscoderClient
-    from mypy_boto3_elastictranscoder import (
+    from mypy_boto3_elastictranscoder.waiter import (
         JobCompleteWaiter,
     )
 
